@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2018, Brandon Nielsen
+# Copyright (c) 2019, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -9,6 +9,9 @@
 class ISOFormatError(ValueError):
     """Raised when ISO 8601 string fails a format check."""
 
+class NegativeDurationError(ValueError):
+    """Raised when a duration is negative."""
+
 class RelativeValueError(ValueError):
     """Raised when an invalid value is given for calendar level accuracy."""
 
